/* --------------------------------------------------
Author: Anastasios Pallas / tcpallas@gmail.com
Version 1.0
Last Update: 2018-12-20
-------------------------------------------------- */


// Update stage will render next frame
createjs.Ticker.framerate = 30;
createjs.Ticker.addEventListener("tick", tickHandler);

function tickHandler(e) {
	stage.update();
}


function handleAudioLoad(event) {
	// Play the loaded sound
	createjs.Sound.play(event.src);
}




function update_status(status) {

	switch(status) {
		case "off":
			clearTimeout(connection_timer);
			connection_status = "off";
			$("#btn_send_digital").hide();
			$("#btn_send_char").hide();
			$("#downtime").hide();
			pc1_off.visible = true;
			pc2_off.visible = true;
			pc1_on.visible = false;
			pc2_on.visible = false;
			pc1_screen_txt.visible = false;
			pc2_screen_txt.visible = false;
			analog_line.visible = false;
			cloud.visible = false;
			pc1_digital_char_container.visible = false;
			pc1_digital_digits_container.visible = false;
			pc2_digital_char_container.visible = false;
			pc2_digital_digits_container.visible = false;
			digital_sign_container.visible = false;
			analog_box_container.visible = false;
			analog_sign_container.visible = false;
			analog_spot.visible = false;
			digital_spot.visible = false;
			status_box.graphics.clear().beginFill("#ffffff").beginStroke("#a1a1a1").setStrokeStyle(3).drawRoundRect(0, 0, 450, 60, 10);
			status_box_txt.text = config.status_off_text;
			status_box_txt.color = "#006699";
			sound_icon.visible = false;
			createjs.Sound.stop(); 						// stop sound
			createjs.Tween.removeTweens(analog_spot);	// stop animation of analog spot
			createjs.Tween.removeTweens(digital_spot);	// stop animation of digital spot
			break;
		case "init":
			connection_status = "init";
			$("#btn_send_digital").hide();
			$("#btn_send_char").hide();
			$("#downtime").show();
			pc1_off.visible = false;
			pc2_off.visible = false;
			pc1_on.visible = true;
			pc2_on.visible = true;
			pc1_screen_txt.visible = false;
			pc2_screen_txt.visible = false;
			analog_line.visible = true;
			cloud.visible = true;
			status_box.graphics.clear().beginFill("#ffab18").beginStroke("#a1a1a1").setStrokeStyle(3).drawRoundRect(0, 0, 450, 60, 10);
			status_box_txt.text = config.status_init_text;
			status_box_txt.color = "#ffffff";
			createjs.Tween.get(status_box_txt, {loop:true}).to({alpha:0, visible:false}, 500).to({alpha:1, visible:true}, 500).wait(1500);
			sound_icon.visible = true;
			createjs.Sound.addEventListener("fileload", handleAudioLoad);
			createjs.Sound.registerSounds(sounds, audioPath);
			createjs.Sound.play("dialup");
			//var connection_timer = setTimeout(function(){
			//	update_status("ready");
			//}, 10000); // sound duration is 28sec = 280000
			// connection_status = "ready";
			break;
		case "ready":
			connection_status = "ready";
			$("#btn_send_digital").show();
			$("#btn_send_char").show();
			$("#downtime").hide();
			pc1_off.visible = false;
			pc2_off.visible = false;
			pc1_on.visible = true;
			pc2_on.visible = true;
			pc1_screen_txt.visible = false;
			pc2_screen_txt.visible = false;
			status_box.graphics.clear().beginFill("#0ca9f0").beginStroke("#a1a1a1").setStrokeStyle(3).drawRoundRect(0, 0, 450, 60, 10);
			status_box_txt.text = config.status_ready_text;
			status_box_txt.color = "#ffffff";
			// createjs.Tween.removeTweens(status_box_txt); // Remove any previous Animation
			createjs.Tween.get(status_box_txt, {loop:false, override:true}).to({alpha:1, visible:true}, 500);
			status_box_txt.visible = true;
			sound_icon.visible = false;
			createjs.Sound.stop();
			break;
		case "send":
			connection_status = "send";
			$("#btn_send_digital").hide();
			$("#btn_send_char").hide();
			$("#downtime").hide();
			pc1_screen_txt.visible = true;
			pc2_screen_txt.visible = false;
			status_box.graphics.clear().beginFill("#eb212e").beginStroke("#a1a1a1").setStrokeStyle(3).drawRoundRect(0, 0, 450, 60, 10);
			status_box_txt.text = config.status_send_text;
			status_box_txt.color = "#ffffff";
			createjs.Tween.get(status_box_txt, {loop:true}).to({alpha:0, visible:false}, 500).to({alpha:1, visible:true}, 500).wait(1500);
			sound_icon.visible = false;
			break;
		case "success":
			connection_status = "success";
			pc1_screen_txt.visible = false;
			pc2_screen_txt.visible = true;
			status_box.graphics.clear().beginFill("#617104").beginStroke("#a1a1a1").setStrokeStyle(3).drawRoundRect(0, 0, 450, 60, 10);
			status_box_txt.text = config.status_success_text;
			status_box_txt.color = "#ffffff";
			createjs.Tween.get(status_box_txt, {loop:false, override:true}).to({alpha:1, visible:true}, 500);
			sound_icon.visible = false;
			analog_box_container.visible = true;
			analog_sign_container.visible = true;
			// set status to ready again after 3 sec
			var success_timer = setTimeout(function(){
				status_box.graphics.clear().beginFill("#0ca9f0").beginStroke("#a1a1a1").setStrokeStyle(3).drawRoundRect(0, 0, 450, 60, 10);
				status_box_txt.text = config.status_ready2_text;
				status_box_txt.color = "#ffffff";
				createjs.Tween.get(status_box_txt, {loop:false, override:true}).to({alpha:1, visible:true}, 500);
				$("#btn_send_digital").show();
				$("#btn_send_char").show();
				$("#downtime").hide();
				connection_status = "ready";
			}, 3000);
			break;
	}
	
	// Update stage
	stage.update();

	return true;

}


function show_animation() {
	
	// Digital Transmission on Sender (PC 1)

	if (send_type=='digits') {
		// digits
		pc1_digital_char_container.visible = false;
		pc1_digital_digits_container.visible = true;
		digital_sign_container.x = 0;
		digital_sign_container.y = 0;
	} else {
		// char
		pc1_digital_char_container.visible = true;
		pc1_digital_digits_container.visible = false;
		digital_sign_container.x = - 55;
		digital_sign_container.y = 0;
	}
	digital_sign_container.visible = true;

	digital_spot.x = config.center_x - 375;
	digital_spot.y = config.center_y - 14;

	createjs.Tween.get(digital_spot)
		.to({alpha:1, visible:true}, 1000)
		.to({y:config.center_y + 12}, 1000)
		.to({x:config.center_x - 235}, 3000)
		.to({alpha:0, visible:false}, 1000)
		.call( show_animation2 );

	stage.update();

}

function show_animation2() {
	
	// Analog Transmission (between modems)

	pc1_digital_char_container.visible = false;
	pc1_digital_digits_container.visible = false;
	digital_sign_container.visible = false;

	analog_box_container.visible = true;
	analog_sign_container.visible = true;

	analog_spot.x = config.center_x - 173;
	analog_spot.y = config.center_y - 5;

	createjs.Tween.get(analog_spot)
		.to({alpha:1, visible:true}, 1000)
		.to({y:config.center_y - 25}, 1000)
		.to({x:config.center_x + 168}, 4000)
		.to({y:config.center_y - 5}, 1000)
		.to({alpha:0, visible:false}, 1000)
		.call( show_animation3 );

	stage.update();

}

function show_animation3() {
	
	// Digital Transmission on Resiver (PC 2)
	// analog_box_container.visible = false;
	// analog_sign_container.visible = false;

	if (send_type=='digits') {
		// digits
		pc2_digital_char_container.visible = false;
		pc2_digital_digits_container.visible = true;
		digital_sign_container.x = 560;
		digital_sign_container.y = 0;
	} else {
		// char
		pc2_digital_char_container.visible = true;
		pc2_digital_digits_container.visible = false;
		digital_sign_container.x = 470;
		digital_sign_container.y = 0;
	}
	digital_sign_container.visible = true;

	digital_spot.x = config.center_x + 240;
	digital_spot.y = config.center_y + 12;

	createjs.Tween.get(digital_spot)
		.to({alpha:1, visible:true}, 1000)
		.to({x:config.center_x + 375}, 3000)
		.to({y:config.center_y - 14}, 1000)
		.to({alpha:0, visible:false}, 1000)
		.call(animation_complete);

	stage.update();

}

function animation_complete() {

	update_status("success");

}


function send_message(bits) {

	pc1_digital_char_container.visible = false;
	pc1_digital_digits_container.visible = false;
	pc2_digital_char_container.visible = false;
	pc2_digital_digits_container.visible = false;
	digital_sign_container.visible = false;

	analog_box_container.visible = false;
	analog_sign_container.visible = false;

	stage.update();

	if (bits.length == 2) {
		
		send_type = 'digits';

		// Update digital sign container
		digital_sign_container.removeAllChildren();
		digital_sign_container.addChild(digital_grid_digits);
		digital_sign_container.addChild(digital_sign_txt);

		// Update analog sign container
		analog_sign_container.removeAllChildren();
		analog_sign_container.addChild(analog_grid);
		analog_sign_container.addChild(analog_sign_txt);

		switch (bits) {
			case "00":
				digital_sign_txt.text = "0  0";
				digital_sign_container.addChild(digital_sign_00);
				analog_sign_txt.text = "00";
				analog_sign_container.addChild(sinewave_00);
				break;
			case "01":
				digital_sign_txt.text = "0  1";
				digital_sign_container.addChild(digital_sign_01);
				analog_sign_txt.text = "01";
				analog_sign_container.addChild(sinewave_01);
				break;
			case "10":
				digital_sign_txt.text = "1  0";
				digital_sign_container.addChild(digital_sign_10);
				analog_sign_txt.text = "10";
				analog_sign_container.addChild(sinewave_10);
				break;
			case "11":
				digital_sign_txt.text = "1  1";
				digital_sign_container.addChild(digital_sign_11);
				analog_sign_txt.text = "11";
				analog_sign_container.addChild(sinewave_11);
				break;
		}

		// Show animation
		show_animation();

	} else if (bits.length == 8) {
		
		send_type = 'char';

		// Sign labels
		digital_sign_txt.text = bits[0] + "  " + bits[1] + "  " + bits[2] + "  " + bits[3] + " " + bits[4] + "  " + bits[5] + "  " + bits[6] + "  " + bits[7];
		analog_sign_txt.text  = bits[0] + bits[1] + "    " + bits[2] + bits[3] + "   " + bits[4] + bits[5] + "    " + bits[6] + bits[7];

		// Create 8-bits digital sign
		digital_sign_8bits.graphics.clear().beginStroke("#01c0f6").setStrokeStyle(2).moveTo(0, 0);

		var bits_x = 0;
		var bits_y = 0;

		if (bits[0]=="0") {
			digital_sign_8bits.graphics.lineTo(25, 0);
			bits_x = 25;
			bits_y = 0;
		} else {
			digital_sign_8bits.graphics.moveTo(0, -25).lineTo(25, -25);
			bits_x = 25;
			bits_y = -25;
		}

		for (i=1; i<8; i++) {

			if (bits[i]=="0") {
				// bit=0
				if (bits[i-1]=="0") {
					digital_sign_8bits.graphics.lineTo(bits_x + 25, 0);
				} else {
					digital_sign_8bits.graphics.lineTo(bits_x, 0).lineTo(bits_x + 25, 0);
				}		
			} else {
				// bit=1
				if (bits[i-1]=="0") {
					digital_sign_8bits.graphics.lineTo(bits_x, -25).lineTo(bits_x + 25, -25);
				} else {
					digital_sign_8bits.graphics.lineTo(bits_x + 25, -25);
				}
			}
			bits_x += 25;
		}

		// update digital sign container
		digital_sign_container.removeAllChildren();
		digital_sign_container.addChild(digital_grid_char);
		digital_sign_container.addChild(digital_sign_8bits);
		digital_sign_container.addChild(digital_sign_txt);

		// Create 8-bits analog waves
		analog_sign_container.removeAllChildren();
		analog_sign_container.addChild(analog_grid);
		analog_sign_container.addChild(analog_sign_txt);

		var sinewave = new Array();
		var sinewave_x = config.center_x - 105;

		for (i=0; i<8; i+=2) {

			sinewave_x = (config.center_x - 105) + (i * 25);
			// console.log(sinewave_x);

			if ( bits[i] + bits[i+1] == "00" ) {
				sinewave[i] = sinewave_00.clone();
				sinewave[i].x = sinewave_x;
				analog_sign_container.addChild(sinewave[i]);
			} else if ( bits[i] + bits[i+1] == "01" ) {
				sinewave[i] = sinewave_01.clone();
				sinewave[i].x = sinewave_x;
				analog_sign_container.addChild(sinewave[i]);
			} else if ( bits[i] + bits[i+1] == "10" ) {
				sinewave[i] = sinewave_10.clone();
				sinewave[i].x = sinewave_x;
				analog_sign_container.addChild(sinewave[i]);
			} else if ( bits[i] + bits[i+1] == "11" ) {
				sinewave[i] = sinewave_11.clone();
				sinewave[i].x = sinewave_x;
				analog_sign_container.addChild(sinewave[i]);
			}

			stage.update();

		}

		// Show animation
		show_animation();

	}

	stage.update();

	return true;

}
